<?php

namespace Annie\Activity\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Annie\Activity\Http\Requests\ActivityRequest;
use Annie\Activity\Models\Activity;

/**
 * Admin web controller class.
 */
class ActivityWorkflowController extends BaseController
{

    /**
     * Workflow controller function for activity.
     *
     * @param Model   $activity
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(ActivityRequest $request, Activity $activity, $step)
    {

        try {

            $activity->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('activity::activity.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/activity/activity/' . $activity->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/activity/activity/' . $activity->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for activity.
     *
     * @param Model   $activity
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Activity $activity, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $activity->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('activity::activity.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('activity::admin.activity.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('activity::admin.activity.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('activity::admin.activity.message', $data)->render();

        }

    }
}
