<?php

namespace Annie\Activity\Policies;

use Litepie\User\Contracts\UserPolicy;
use Annie\Activity\Models\ActivityActivityArea;

class ActivityActivityAreaPolicy
{

    /**
     * Determine if the given user can view the activity_activity_area.
     *
     * @param UserPolicy $user
     * @param ActivityActivityArea $activity_activity_area
     *
     * @return bool
     */
    public function view(UserPolicy $user, ActivityActivityArea $activity_activity_area)
    {
        if ($user->canDo('activity.activity_activity_area.view') && $user->isAdmin()) {
            return true;
        }

        return $activity_activity_area->user_id == user_id() && $activity_activity_area->user_type == user_type();
    }

    /**
     * Determine if the given user can create a activity_activity_area.
     *
     * @param UserPolicy $user
     * @param ActivityActivityArea $activity_activity_area
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('activity.activity_activity_area.create');
    }

    /**
     * Determine if the given user can update the given activity_activity_area.
     *
     * @param UserPolicy $user
     * @param ActivityActivityArea $activity_activity_area
     *
     * @return bool
     */
    public function update(UserPolicy $user, ActivityActivityArea $activity_activity_area)
    {
        if ($user->canDo('activity.activity_activity_area.edit') && $user->isAdmin()) {
            return true;
        }

        return $activity_activity_area->user_id == user_id() && $activity_activity_area->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given activity_activity_area.
     *
     * @param UserPolicy $user
     * @param ActivityActivityArea $activity_activity_area
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ActivityActivityArea $activity_activity_area)
    {
        return $activity_activity_area->user_id == user_id() && $activity_activity_area->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given activity_activity_area.
     *
     * @param UserPolicy $user
     * @param ActivityActivityArea $activity_activity_area
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ActivityActivityArea $activity_activity_area)
    {
        if ($user->canDo('activity.activity_activity_area.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given activity_activity_area.
     *
     * @param UserPolicy $user
     * @param ActivityActivityArea $activity_activity_area
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ActivityActivityArea $activity_activity_area)
    {
        if ($user->canDo('activity.activity_activity_area.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
