<?php

namespace Annie\Activity\Policies;

use Litepie\User\Contracts\UserPolicy;
use Annie\Activity\Models\ActivityCollage;

class ActivityCollagePolicy
{

    /**
     * Determine if the given user can view the activity_collage.
     *
     * @param UserPolicy $user
     * @param ActivityCollage $activity_collage
     *
     * @return bool
     */
    public function view(UserPolicy $user, ActivityCollage $activity_collage)
    {
        if ($user->canDo('activity.activity_collage.view') && $user->isAdmin()) {
            return true;
        }

        return $activity_collage->user_id == user_id() && $activity_collage->user_type == user_type();
    }

    /**
     * Determine if the given user can create a activity_collage.
     *
     * @param UserPolicy $user
     * @param ActivityCollage $activity_collage
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('activity.activity_collage.create');
    }

    /**
     * Determine if the given user can update the given activity_collage.
     *
     * @param UserPolicy $user
     * @param ActivityCollage $activity_collage
     *
     * @return bool
     */
    public function update(UserPolicy $user, ActivityCollage $activity_collage)
    {
        if ($user->canDo('activity.activity_collage.edit') && $user->isAdmin()) {
            return true;
        }

        return $activity_collage->user_id == user_id() && $activity_collage->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given activity_collage.
     *
     * @param UserPolicy $user
     * @param ActivityCollage $activity_collage
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ActivityCollage $activity_collage)
    {
        return $activity_collage->user_id == user_id() && $activity_collage->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given activity_collage.
     *
     * @param UserPolicy $user
     * @param ActivityCollage $activity_collage
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ActivityCollage $activity_collage)
    {
        if ($user->canDo('activity.activity_collage.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given activity_collage.
     *
     * @param UserPolicy $user
     * @param ActivityCollage $activity_collage
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ActivityCollage $activity_collage)
    {
        if ($user->canDo('activity.activity_collage.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
