<?php

namespace Annie\Activity\Policies;

use Litepie\User\Contracts\UserPolicy;
use Annie\Activity\Models\ActivityCommunity;

class ActivityCommunityPolicy
{

    /**
     * Determine if the given user can view the activity_community.
     *
     * @param UserPolicy $user
     * @param ActivityCommunity $activity_community
     *
     * @return bool
     */
    public function view(UserPolicy $user, ActivityCommunity $activity_community)
    {
        if ($user->canDo('activity.activity_community.view') && $user->isAdmin()) {
            return true;
        }

        return $activity_community->user_id == user_id() && $activity_community->user_type == user_type();
    }

    /**
     * Determine if the given user can create a activity_community.
     *
     * @param UserPolicy $user
     * @param ActivityCommunity $activity_community
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('activity.activity_community.create');
    }

    /**
     * Determine if the given user can update the given activity_community.
     *
     * @param UserPolicy $user
     * @param ActivityCommunity $activity_community
     *
     * @return bool
     */
    public function update(UserPolicy $user, ActivityCommunity $activity_community)
    {
        if ($user->canDo('activity.activity_community.edit') && $user->isAdmin()) {
            return true;
        }

        return $activity_community->user_id == user_id() && $activity_community->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given activity_community.
     *
     * @param UserPolicy $user
     * @param ActivityCommunity $activity_community
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ActivityCommunity $activity_community)
    {
        return $activity_community->user_id == user_id() && $activity_community->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given activity_community.
     *
     * @param UserPolicy $user
     * @param ActivityCommunity $activity_community
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ActivityCommunity $activity_community)
    {
        if ($user->canDo('activity.activity_community.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given activity_community.
     *
     * @param UserPolicy $user
     * @param ActivityCommunity $activity_community
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ActivityCommunity $activity_community)
    {
        if ($user->canDo('activity.activity_community.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
