<?php

namespace Annie\Activity\Policies;

use Litepie\User\Contracts\UserPolicy;
use Annie\Activity\Models\Activity;

class ActivityPolicy
{

    /**
     * Determine if the given user can view the activity.
     *
     * @param UserPolicy $user
     * @param Activity $activity
     *
     * @return bool
     */
    public function view(UserPolicy $user, Activity $activity)
    {
        if ($user->canDo('activity.activity.view') && $user->isAdmin()) {
            return true;
        }

        return $activity->user_id == user_id() && $activity->user_type == user_type();
    }

    /**
     * Determine if the given user can create a activity.
     *
     * @param UserPolicy $user
     * @param Activity $activity
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('activity.activity.create');
    }

    /**
     * Determine if the given user can update the given activity.
     *
     * @param UserPolicy $user
     * @param Activity $activity
     *
     * @return bool
     */
    public function update(UserPolicy $user, Activity $activity)
    {
        if ($user->canDo('activity.activity.edit') && $user->isAdmin()) {
            return true;
        }

        return $activity->user_id == user_id() && $activity->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given activity.
     *
     * @param UserPolicy $user
     * @param Activity $activity
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Activity $activity)
    {
        return $activity->user_id == user_id() && $activity->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given activity.
     *
     * @param UserPolicy $user
     * @param Activity $activity
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Activity $activity)
    {
        if ($user->canDo('activity.activity.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given activity.
     *
     * @param UserPolicy $user
     * @param Activity $activity
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Activity $activity)
    {
        if ($user->canDo('activity.activity.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
