<?php

namespace Annie\Activity\Policies;

use Litepie\User\Contracts\UserPolicy;
use Annie\Activity\Models\ActivityProgramme;

class ActivityProgrammePolicy
{

    /**
     * Determine if the given user can view the activity_programme.
     *
     * @param UserPolicy $user
     * @param ActivityProgramme $activity_programme
     *
     * @return bool
     */
    public function view(UserPolicy $user, ActivityProgramme $activity_programme)
    {
        if ($user->canDo('activity.activity_programme.view') && $user->isAdmin()) {
            return true;
        }

        return $activity_programme->user_id == user_id() && $activity_programme->user_type == user_type();
    }

    /**
     * Determine if the given user can create a activity_programme.
     *
     * @param UserPolicy $user
     * @param ActivityProgramme $activity_programme
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('activity.activity_programme.create');
    }

    /**
     * Determine if the given user can update the given activity_programme.
     *
     * @param UserPolicy $user
     * @param ActivityProgramme $activity_programme
     *
     * @return bool
     */
    public function update(UserPolicy $user, ActivityProgramme $activity_programme)
    {
        if ($user->canDo('activity.activity_programme.edit') && $user->isAdmin()) {
            return true;
        }

        return $activity_programme->user_id == user_id() && $activity_programme->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given activity_programme.
     *
     * @param UserPolicy $user
     * @param ActivityProgramme $activity_programme
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ActivityProgramme $activity_programme)
    {
        return $activity_programme->user_id == user_id() && $activity_programme->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given activity_programme.
     *
     * @param UserPolicy $user
     * @param ActivityProgramme $activity_programme
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ActivityProgramme $activity_programme)
    {
        if ($user->canDo('activity.activity_programme.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given activity_programme.
     *
     * @param UserPolicy $user
     * @param ActivityProgramme $activity_programme
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ActivityProgramme $activity_programme)
    {
        if ($user->canDo('activity.activity_programme.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
