<?php

namespace Annie\Activity\Policies;

use Litepie\User\Contracts\UserPolicy;
use Annie\Activity\Models\ActivitySchool;

class ActivitySchoolPolicy
{

    /**
     * Determine if the given user can view the activity_school.
     *
     * @param UserPolicy $user
     * @param ActivitySchool $activity_school
     *
     * @return bool
     */
    public function view(UserPolicy $user, ActivitySchool $activity_school)
    {
        if ($user->canDo('activity.activity_school.view') && $user->isAdmin()) {
            return true;
        }

        return $activity_school->user_id == user_id() && $activity_school->user_type == user_type();
    }

    /**
     * Determine if the given user can create a activity_school.
     *
     * @param UserPolicy $user
     * @param ActivitySchool $activity_school
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('activity.activity_school.create');
    }

    /**
     * Determine if the given user can update the given activity_school.
     *
     * @param UserPolicy $user
     * @param ActivitySchool $activity_school
     *
     * @return bool
     */
    public function update(UserPolicy $user, ActivitySchool $activity_school)
    {
        if ($user->canDo('activity.activity_school.edit') && $user->isAdmin()) {
            return true;
        }

        return $activity_school->user_id == user_id() && $activity_school->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given activity_school.
     *
     * @param UserPolicy $user
     * @param ActivitySchool $activity_school
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ActivitySchool $activity_school)
    {
        return $activity_school->user_id == user_id() && $activity_school->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given activity_school.
     *
     * @param UserPolicy $user
     * @param ActivitySchool $activity_school
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ActivitySchool $activity_school)
    {
        if ($user->canDo('activity.activity_school.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given activity_school.
     *
     * @param UserPolicy $user
     * @param ActivitySchool $activity_school
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ActivitySchool $activity_school)
    {
        if ($user->canDo('activity.activity_school.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
