<?php

namespace Annie\Activity\Policies;

use Litepie\User\Contracts\UserPolicy;
use Annie\Activity\Models\ActivitySocialPartner;

class ActivitySocialPartnerPolicy
{

    /**
     * Determine if the given user can view the activity_social_partner.
     *
     * @param UserPolicy $user
     * @param ActivitySocialPartner $activity_social_partner
     *
     * @return bool
     */
    public function view(UserPolicy $user, ActivitySocialPartner $activity_social_partner)
    {
        if ($user->canDo('activity.activity_social_partner.view') && $user->isAdmin()) {
            return true;
        }

        return $activity_social_partner->user_id == user_id() && $activity_social_partner->user_type == user_type();
    }

    /**
     * Determine if the given user can create a activity_social_partner.
     *
     * @param UserPolicy $user
     * @param ActivitySocialPartner $activity_social_partner
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('activity.activity_social_partner.create');
    }

    /**
     * Determine if the given user can update the given activity_social_partner.
     *
     * @param UserPolicy $user
     * @param ActivitySocialPartner $activity_social_partner
     *
     * @return bool
     */
    public function update(UserPolicy $user, ActivitySocialPartner $activity_social_partner)
    {
        if ($user->canDo('activity.activity_social_partner.edit') && $user->isAdmin()) {
            return true;
        }

        return $activity_social_partner->user_id == user_id() && $activity_social_partner->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given activity_social_partner.
     *
     * @param UserPolicy $user
     * @param ActivitySocialPartner $activity_social_partner
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ActivitySocialPartner $activity_social_partner)
    {
        return $activity_social_partner->user_id == user_id() && $activity_social_partner->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given activity_social_partner.
     *
     * @param UserPolicy $user
     * @param ActivitySocialPartner $activity_social_partner
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ActivitySocialPartner $activity_social_partner)
    {
        if ($user->canDo('activity.activity_social_partner.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given activity_social_partner.
     *
     * @param UserPolicy $user
     * @param ActivitySocialPartner $activity_social_partner
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ActivitySocialPartner $activity_social_partner)
    {
        if ($user->canDo('activity.activity_social_partner.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
