<?php

namespace Annie\Activity\Policies;

use Litepie\User\Contracts\UserPolicy;
use Annie\Activity\Models\ActivityWorkArea;

class ActivityWorkAreaPolicy
{

    /**
     * Determine if the given user can view the activity_work_area.
     *
     * @param UserPolicy $user
     * @param ActivityWorkArea $activity_work_area
     *
     * @return bool
     */
    public function view(UserPolicy $user, ActivityWorkArea $activity_work_area)
    {
        if ($user->canDo('activity.activity_work_area.view') && $user->isAdmin()) {
            return true;
        }

        return $activity_work_area->user_id == user_id() && $activity_work_area->user_type == user_type();
    }

    /**
     * Determine if the given user can create a activity_work_area.
     *
     * @param UserPolicy $user
     * @param ActivityWorkArea $activity_work_area
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('activity.activity_work_area.create');
    }

    /**
     * Determine if the given user can update the given activity_work_area.
     *
     * @param UserPolicy $user
     * @param ActivityWorkArea $activity_work_area
     *
     * @return bool
     */
    public function update(UserPolicy $user, ActivityWorkArea $activity_work_area)
    {
        if ($user->canDo('activity.activity_work_area.edit') && $user->isAdmin()) {
            return true;
        }

        return $activity_work_area->user_id == user_id() && $activity_work_area->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given activity_work_area.
     *
     * @param UserPolicy $user
     * @param ActivityWorkArea $activity_work_area
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ActivityWorkArea $activity_work_area)
    {
        return $activity_work_area->user_id == user_id() && $activity_work_area->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given activity_work_area.
     *
     * @param UserPolicy $user
     * @param ActivityWorkArea $activity_work_area
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ActivityWorkArea $activity_work_area)
    {
        if ($user->canDo('activity.activity_work_area.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given activity_work_area.
     *
     * @param UserPolicy $user
     * @param ActivityWorkArea $activity_work_area
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ActivityWorkArea $activity_work_area)
    {
        if ($user->canDo('activity.activity_work_area.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
