<?php

namespace Annie\Activity\Providers;

use Illuminate\Support\ServiceProvider;

class ActivityServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'activity');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'activity');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerActivity();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerActivity()
    {
        $this->app->bind('activity', function($app) {
            return new Activity($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Activity', 'Lavalite\Activity\Facades\Activity');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('annie.activity', function ($app) {
            return $this->app->make('Annie\Activity\Activity');
        });

        // Bind Activity to repository
        $this->app->bind(
            'Annie\Activity\Interfaces\ActivityRepositoryInterface',
            \Annie\Activity\Repositories\Eloquent\ActivityRepository::class
        );
        // Bind ActivityActivityArea to repository
        $this->app->bind(
            'Annie\Activity\Interfaces\ActivityActivityAreaRepositoryInterface',
            \Annie\Activity\Repositories\Eloquent\ActivityActivityAreaRepository::class
        );
        // Bind ActivityArea to repository
        $this->app->bind(
            'Annie\Activity\Interfaces\ActivityAreaRepositoryInterface',
            \Annie\Activity\Repositories\Eloquent\ActivityAreaRepository::class
        );
        // Bind ActivityCollage to repository
        $this->app->bind(
            'Annie\Activity\Interfaces\ActivityCollageRepositoryInterface',
            \Annie\Activity\Repositories\Eloquent\ActivityCollageRepository::class
        );
        // Bind ActivityCommunity to repository
        $this->app->bind(
            'Annie\Activity\Interfaces\ActivityCommunityRepositoryInterface',
            \Annie\Activity\Repositories\Eloquent\ActivityCommunityRepository::class
        );
        // Bind ActivityProgramme to repository
        $this->app->bind(
            'Annie\Activity\Interfaces\ActivityProgrammeRepositoryInterface',
            \Annie\Activity\Repositories\Eloquent\ActivityProgrammeRepository::class
        );
        // Bind ActivitySchool to repository
        $this->app->bind(
            'Annie\Activity\Interfaces\ActivitySchoolRepositoryInterface',
            \Annie\Activity\Repositories\Eloquent\ActivitySchoolRepository::class
        );
        // Bind ActivitySocialPartner to repository
        $this->app->bind(
            'Annie\Activity\Interfaces\ActivitySocialPartnerRepositoryInterface',
            \Annie\Activity\Repositories\Eloquent\ActivitySocialPartnerRepository::class
        );
        // Bind ActivityWorkArea to repository
        $this->app->bind(
            'Annie\Activity\Interfaces\ActivityWorkAreaRepositoryInterface',
            \Annie\Activity\Repositories\Eloquent\ActivityWorkAreaRepository::class
        );

        $this->app->register(\Annie\Activity\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Annie\Activity\Providers\RouteServiceProvider::class);
                $this->app->register(\Annie\Activity\Providers\WorkflowServiceProvider::class);
            }

    /**
     * Merges user's and activity's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/activity.php', 'activity'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeActivity::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['annie.activity'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('annie/activity.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/activity')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/activity')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
