<?php

namespace Annie\Activity\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Annie\Activity\Models\Activity;

class ActivityAction
{
    /**
     * Perform the complete action.
     *
     * @param Activity $activity
     *
     * @return Activity
     */
    public function complete(Activity $activity)
    {
        try {
            $activity->status = 'complete';
            return $activity->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Activity $activity
     *
     * @return Activity
     */public function verify(Activity $activity)
    {
        try {
            $activity->status = 'verify';
            return $activity->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Activity $activity
     *
     * @return Activity
     */public function approve(Activity $activity)
    {
        try {
            $activity->status = 'approve';
            return $activity->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Activity $activity
     *
     * @return Activity
     */public function publish(Activity $activity)
    {
        try {
            $activity->status = 'publish';
            return $activity->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Activity $activity
     *
     * @return Activity
     */
    public function archive(Activity $activity)
    {
        try {
            $activity->status = 'archive';
            return $activity->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Activity $activity
     *
     * @return Activity
     */
    public function unpublish(Activity $activity)
    {
        try {
            $activity->status = 'unpublish';
            return $activity->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
