<?php

namespace Annie\Activity\Workflow;

use Annie\Activity\Models\Activity;
use Validator;

class ActivityValidator
{

    /**
     * Determine if the given activity is valid for complete status.
     *
     * @param Activity $activity
     *
     * @return bool / Validator
     */
    public function complete(Activity $activity)
    {
        return Validator::make($activity->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given activity is valid for verify status.
     *
     * @param Activity $activity
     *
     * @return bool / Validator
     */
    public function verify(Activity $activity)
    {
        return Validator::make($activity->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given activity is valid for approve status.
     *
     * @param Activity $activity
     *
     * @return bool / Validator
     */
    public function approve(Activity $activity)
    {
        return Validator::make($activity->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given activity is valid for publish status.
     *
     * @param Activity $activity
     *
     * @return bool / Validator
     */
    public function publish(Activity $activity)
    {
        return Validator::make($activity->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given activity is valid for archive status.
     *
     * @param Activity $activity
     *
     * @return bool / Validator
     */
    public function archive(Activity $activity)
    {
        return Validator::make($activity->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given activity is valid for unpublish status.
     *
     * @param Activity $activity
     *
     * @return bool / Validator
     */
    public function unpublish(Activity $activity)
    {
        return Validator::make($activity->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
